==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ResourceGuardOperationDetailArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VaultCritical Operation protected by a resource guard
 * @property defaultResourceRequest
 * @property vaultCriticalOperation
 */
public data class ResourceGuardOperationDetailArgs(
    public val defaultResourceRequest: Output<String>? = null,
    public val vaultCriticalOperation: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs =
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs.builder()
            .defaultResourceRequest(defaultResourceRequest?.applyValue({ args0 -> args0 }))
            .vaultCriticalOperation(vaultCriticalOperation?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardOperationDetailArgs].
 */
@PulumiTagMarker
public class ResourceGuardOperationDetailArgsBuilder internal constructor() {
    private var defaultResourceRequest: Output<String>? = null

    private var vaultCriticalOperation: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("csbdqpcqnpyaehsx")
    public suspend fun defaultResourceRequest(`value`: Output<String>) {
        this.defaultResourceRequest = value
    }

    /**
     * @param value
     */
    @JvmName("tdctxwlsdloeepsk")
    public suspend fun vaultCriticalOperation(`value`: Output<String>) {
        this.vaultCriticalOperation = value
    }

    /**
     * @param value
     */
    @JvmName("rhkjqenhenydtekh")
    public suspend fun defaultResourceRequest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultResourceRequest = mapped
    }

    /**
     * @param value
     */
    @JvmName("feqpvennwtvudyiy")
    public suspend fun vaultCriticalOperation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vaultCriticalOperation = mapped
    }

    internal fun build(): ResourceGuardOperationDetailArgs = ResourceGuardOperationDetailArgs(
        defaultResourceRequest = defaultResourceRequest,
        vaultCriticalOperation = vaultCriticalOperation,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ResourceGuardOperationDetailArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VaultCritical Operation protected by a resource guard
 * @property defaultResourceRequest
 * @property vaultCriticalOperation
 */
public data class ResourceGuardOperationDetailArgs(
    public val defaultResourceRequest: Output<String>? = null,
    public val vaultCriticalOperation: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs =
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardOperationDetailArgs.builder()
            .defaultResourceRequest(defaultResourceRequest?.applyValue({ args0 -> args0 }))
            .vaultCriticalOperation(vaultCriticalOperation?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardOperationDetailArgs].
 */
@PulumiTagMarker
public class ResourceGuardOperationDetailArgsBuilder internal constructor() {
    private var defaultResourceRequest: Output<String>? = null

    private var vaultCriticalOperation: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("hfufsygckcqcjnkl")
    public suspend fun defaultResourceRequest(`value`: Output<String>) {
        this.defaultResourceRequest = value
    }

    /**
     * @param value
     */
    @JvmName("hxnmqjqgfrsfbaqb")
    public suspend fun vaultCriticalOperation(`value`: Output<String>) {
        this.vaultCriticalOperation = value
    }

    /**
     * @param value
     */
    @JvmName("svmkxvdenqvkqvao")
    public suspend fun defaultResourceRequest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultResourceRequest = mapped
    }

    /**
     * @param value
     */
    @JvmName("naxqwtwpxaaohxbm")
    public suspend fun vaultCriticalOperation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vaultCriticalOperation = mapped
    }

    internal fun build(): ResourceGuardOperationDetailArgs = ResourceGuardOperationDetailArgs(
        defaultResourceRequest = defaultResourceRequest,
        vaultCriticalOperation = vaultCriticalOperation,
    )
}
